@@ -317,11 +317,11 @@ if(type==1) {
    bool keeptest,/*keeptestme*/keeptreedraw,type1sigest=(type==1 && lambda!=0.);
 
    time_t tp;
-   int time1 = time(&tp), total=nd+burn;
+   int time1 = time(&tp);// total=nd+burn;
    xinfo& xi = bm.getxinfo();
-
-   for(size_t i=0;i<(size_t)total;i++) {
-      if(i%printevery==0) printf("done %zu (out of %lu)\n",i,nd+burn);
+   size_t total=nd+burn;
+   for(size_t i=0;i<total;i++) {
+      if(i%printevery==0) printf("done %zu (out of %zu)\n",i,total);//nd+burn);
       //if(i%printevery==0) printf("%22zu/%zu\r",i,total);
       if(i==(burn/2)&&dart) bm.startdart();
       //draw bart
